import src.vfscript.cluster_processing.cluster_macth
import src.vfscript.cluster_processing.cluster_processor
import src.vfscript.cluster_processing.cluster_processor_machine
import src.vfscript.cluster_processing.export_cluster_list
import src.vfscript.cluster_processing.key_files_separator


import src.vfscript.training.cristal_structure_gen
import src.vfscript.training.synthetic_data
import src.vfscript.training.training_fingerstyle
import src.vfscript.training.training_processor
import src.vfscript.training.utils
import src.vfscript.training.vacancy_predictor_curve
import src.vfscript.training.vacancy_predictors


# modifiers/training/utils.py

import os
import json
import pandas as pd

def load_json_data(json_path: str) -> pd.DataFrame:
    """
    Lee un JSON del disco y devuelve un DataFrame de pandas con su contenido.
    """
    with open(json_path, "r", encoding="utf-8") as f:
        data = json.load(f)
    return pd.DataFrame(data)


def resolve_input_params_path(module_file: str, json_name: str = "input_params.json") -> str:
    """
    Dado el __file__ de un módulo, sube un nivel y
    busca 'input_params.json' en esa carpeta. Si no existe,
    lanza FileNotFoundError.
    """
    carpeta_actual = os.path.dirname(module_file)       # e.g. .../modifiers/training
    carpeta_raiz   = os.path.dirname(carpeta_actual)     # e.g. .../modifiers
    ruta_json = os.path.join(carpeta_raiz, json_name)
    if not os.path.exists(ruta_json):
        raise FileNotFoundError(f"No se encontró '{json_name}' en: {carpeta_raiz}")
    return ruta_json



from setuptools import setup, find_packages 

setup(




    name='vacancycalculator',
    version='0.1.6',
    author='TiagodBe',
    license='MIT',
    description='Defect analysis and vacancy calculation for materials science',
    packages=find_packages(),                                                                                                               
    install_requires=['scikit-learn','pandas','xgboost'],
    author_email='santiagobergamin@gmail.com',
    url='https://github.com/TiagoBe0/VFScript-CDScanner'

)


# src/vfscript/__init__.py
from vfscript.cluster_processing import *
from vfscript.runner import *
from vfscript.utils import *
from vfscript.surface_processor import *
from vfscript.training import *
import vfscript.main
import vfscript.core
import vfscript.params
import vfscript.config_loader